import { DashboardService } from './../../../shared/dashboard.service';
import { Component, OnInit } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { AuthServiceService } from './../../../shared/auth-service.service';
import { ActivatedRoute, Router, Params } from '@angular/router';
import { UserService } from '../../../shared/user.service';
import { NgxSpinnerService } from 'ngx-spinner';
import { ToastrService } from 'ngx-toastr';
import { Overlay } from 'ngx-modialog';
import { Modal } from 'ngx-modialog/plugins/bootstrap';

@Component({
  selector: 'app-supervisor-list',
  templateUrl: './supervisor-list.component.html',
  styleUrls: ['./supervisor-list.component.css']
})
export class SupervisorListComponent implements OnInit {

  superVisorId: number;
  superDepartList = [];
  superDepartListIds = [];
  count: number;
  perPagePagenation: number;
  p: number[] = [];
  currentPage:number = 1;
  filtterStatus = '';
  selectedAll: any;
  userLoginId:number;
  serviceId:number;
  dataTableNumber: number = 5;
  pages = [];
  servicesName: string = '';

  constructor(private route: ActivatedRoute, 
    private router: Router, 
    private userSer: UserService,
    private http: HttpClient,
    private toastr: ToastrService,
    private spinner: NgxSpinnerService,
    private modal: Modal,
    private dashBoardService: DashboardService,
    public authSer: AuthServiceService) { }

  ngOnInit() {
    
    this.spinner.show();
    //init the values of permision boolean
    this.authSer.showAddBtn = false;
    this.authSer.showDeleteBtn = false;
    this.authSer.showEditBtn = false;
    //show / hide notification search in header
    this.authSer.notificationLogin = true;
    this.authSer.showSearchHeader = false;
    this.authSer.showHeaderLogin = false;
    this.authSer.showHeaderDashBoard = true;
    this.authSer.showDashboardHeader = true;
    this.authSer.internalHeader = false;

    
    
    this.route.params.subscribe(
      (params: Params) => {
        this.superVisorId = +params['listPageId'];
        localStorage.setItem('pageIdActive', params['listPageId']);
      }
    );
    
    //to show / hide permissions

  this.route.parent.params.subscribe(
    (params:Params) => {
        this.userLoginId = params['userID'];
        this.serviceId = params['serviceID'];
        this.servicesName = 'خدمه التدريب';

        this.userSer.getPagesPermetiotns(this.userLoginId, this.serviceId).subscribe(
          (responce) => {
            console.log(responce);
            this.pages = responce['pages'];
            for(let i = 0; i< this.pages.length; i++) {
              if(this.pages[i].id == 33) {
                if(this.pages[i]['permissions'][0].name == 'asign_supervisors_to_departments') {
                  this.authSer.showAddBtn = true;
                  this.authSer.showEditBtn = true;
                  this.authSer.showDeleteBtn = true;
                } else {
                  console.log('no permissions');
                }
              } else {
                console.log('no events');
              }
            }
            this.spinner.hide();
          },
          (error) => {console.log(error)}
        );

      }
    );

    //get list data 
    this.dashBoardService.getListData(this.superVisorId, this.currentPage ,this.dataTableNumber).subscribe(
      (responce) => {
        console.log(responce);
        this.superDepartList = responce['departments'];
        this.count = responce['count'];
        this.perPagePagenation = responce['per_page'];
        console.log('evennnnts', this.superDepartList);
        this.spinner.hide();
      },
      (error) => {
        console.log(error);
        this.spinner.hide();
      }
    );
    
  }

  //make all checkbox of user checked 
  selectAll() {
    for (var i = 0; i < this.superDepartList.length; i++) {
      this.superDepartList[i].selected = this.selectedAll;
    }
  }

  checkIfAllSelected() {
    this.selectedAll = this.superDepartList.every(function(item:any) {
      return item.selected == true;
    });
  }

  //filtter function
  filtterFunc(data) {
    this.superDepartList = [];
    console.log(data.target.value);
    const dataSearch = data.target.value;     
    this.currentPage = 1;
    console.log('search curent page', this.currentPage);
    console.log('search page id', this.superVisorId);
    this.dashBoardService.getDataUSerSearchBar(dataSearch, this.superVisorId, this.currentPage, this.dataTableNumber).subscribe(
      (responce) => {
        console.log(responce);
        this.superDepartList = responce['departments'];
        this.count = responce['count'];
        this.perPagePagenation = responce['per_page'];
        console.log('filtter count', this.count);
        console.log('filtter perPagePAgenation', this.perPagePagenation);
      },
      (error) => {
        console.log(error)
      }
    );
  };

  //change pagenation
  onPageChange(pagenationNumber) {
    this.spinner.show();
    this.currentPage = pagenationNumber;
    this.superDepartList = [];
    //console.log(pagenationNumber);
    //console.log(this.pageId);
    this.dashBoardService.getListData(this.superVisorId, pagenationNumber, this.dataTableNumber).subscribe(
      (responce) => {
        console.log(responce);
        this.superDepartList = responce['departments'];
        this.count = responce['count'];
        this.perPagePagenation = responce['per_page'];
        console.log(this.superDepartList);
        this.spinner.hide();
      },
      (error) => {
        console.log(error);
        this.spinner.hide();
      }
    );
  }



  //determine the list count from select element 
  onGetValue(event) {
    this.spinner.show();
    this.superDepartList = [];
    this.dataTableNumber = event.target.value;
    this.dashBoardService.getListData(this.superVisorId, this.currentPage, this.dataTableNumber).subscribe(
      (responce) => {
        console.log(responce);
        this.superDepartList = responce['departments'];
        this.count = responce['count'];
        this.perPagePagenation = responce['per_page'];
        this.spinner.hide();
      },
      (error) => {
        console.log(error);
        this.spinner.hide();
      }
    );
  };
  
  onDelete() {

    this.superDepartListIds = [];
    for(let i = 0; i < this.superDepartList.length; i++) {
      if(this.superDepartList[i].selected == true) {
        this.superDepartListIds.push(this.superDepartList[i].id);
      }
    }

    console.log(this.superDepartListIds);
    if(this.superDepartListIds.length > 0) {
      const dialogRef = this.modal.alert()
      .size('sm')
      .showClose(true)
      .title('تأكيد الحذف')
      .body(`
          <h4>هل ترغب في حذف العناصر المحدده ؟ </h4>
          `)
      .open();
  
        dialogRef.result
        .then( result => 
          this.dashBoardService.deleteItem(this.superDepartListIds, this.superVisorId).subscribe(
              (responce) => {
                console.log(responce);
                this.toastr.success('تم الحذف');
                this.spinner.show();
                this.superDepartList = [];
                this.dashBoardService.getListData(this.superVisorId, this.currentPage, this.dataTableNumber).subscribe(
                  (responce) => {
                    console.log(responce);
                    this.count = responce['count'];
                    this.perPagePagenation = responce['per_page'];
                    this.superDepartList = responce['departments'];
                    if(this.superDepartList.length == 0) {
                      this.toastr.warning('لا يوجد بيانات لعرضها الأن !');
                    }
                    console.log(this.superDepartList);
                    this.spinner.hide();
                  },
                  (error) => {
                    console.log(error);
                    
                  }
                )
              },
              (error) => {
                console.log(error.error.error);
                if(error['error'].error == 'department already has trainees') {
                  this.toastr.warning('القسم به متدربين لايمكن حذفه !');
                } else {
                  this.toastr.error('حدث خطأ رجاء الانتظار وحاول ثانيه');
                }
                this.spinner.hide();
              }
          )
        );
    } else {
      this.toastr.warning('لم يتم أختيار أي عنصر للحذف !');
    }
  };

  //add function
  onAdd() {
    console.log('service/' + this.userLoginId + '/' + this.serviceId + '/superVisor/Add');
    this.router.navigate(['service/' + this.userLoginId + '/' + this.serviceId + '/superVisor/Add']);
  }

  //edit function
   onEdit(editMenuID) {
    this.router.navigate(['service/' + this.userLoginId + '/' + this.serviceId + '/superVisor/edit/' + editMenuID]);
  }

}
